@@ -413,9 +413,14 @@ sub ip {
     eval {
         $ip =
           ( MP() == 2 )
-          ? $apacheRequest->connection->remote_ip
+          ? (
+            Apache::Connection->can('remote_ip')
+            ? $apacheRequest->connection->remote_ip
+            : $apacheRequest->connection->client_ip
+          )
           : $apacheRequest->remote_ip;
     };
+    print STDERR "Error: $@\n" if ($@);
     return $ip;
 }
 
